#ifndef TERMINAL_API_DRIVER_H
#define TERMINAL_API_DRIVER_H

#include <memory>
#include <string>
#include <terminal_api/ControlProtoCInterface.h>


namespace api_driver {

    constexpr int CACHE_STATISTICS_UPDATE_MS = 500;
    constexpr int CACHE_SETTINGS_UPDATE_MS = 5000;

    class TerminalApiDaemon;

    /**
     * Это ApiDriver. Все ответы он будет возвращать в виде json.
     */
    class ApiDriver {
    public:
        explicit ApiDriver();

        /**
         * Запуск демона
         */
        void startDaemon();

        /**
         * Запросить общее состояние терминала
         * @return {"txState":false,"rxState":false,"rx.sym_sync_lock":false,"rx.freq_search_lock":false,"rx.afc_lock":false,"rx.pkt_sync":false}
         */
        std::string loadTerminalState() const;

        /**
         * Сбросить статистику пакетов
         */
        void resetPacketStatistics() const;

        std::string loadSettings() const;

        ~ApiDriver();

    private:
        TSID sid{0};
        unsigned int access{0};

        std::string deviceInitState;
        std::unique_ptr<TerminalApiDaemon> daemon;

        bool getIsCinC() const;
    };
}

#endif //TERMINAL_API_DRIVER_H
